pyrestsdk.type.enum package — PyRESTSDK documentation

# pyrestsdk.type.enum package

## Module contents

Houses enum types

class pyrestsdk.type.enum.FeatureUsageFlag(value, names=None, *, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `IntEnum`

  Enumerated list of values used to flag usage of specific middleware

  AUTH_HANDLER_ENABLED = 4
  DEFAULT_HTTP_PROVIDER_ENABLED = 8
  LOGGING_HANDLER_ENABLED = 16
  NONE = 0
  REDIRECT_HANDLER_ENABLED = 1
  RETRY_HANDLER_ENABLED = 2

class pyrestsdk.type.enum.HttpsMethod(value, names=None, *, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `IntEnum`

  HTTPS Method enum

  DELETE = 3
  GET = 1
  PATCH = 4
  POST = 2
  PUT = 5